==> mobcapture-0.1.3%2B1.21-sources.jar: de/kaama/mobcapture/MobCaptureMod.java <==
package de.kaama.mobcapture;

import net.fabricmc.api.ModInitializer;
import net.minecraft.class_1887;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
//? if >=1.21 {
import com.mojang.serialization.MapCodec;
import de.kaama.mobcapture.enchantment.effect.CapturingEnchantmentEffect;


public class MobCaptureMod implements ModInitializer {

    public static final String MOD_ID = "mobcapture";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);
    public static final String VERSION = /*$ mod_version*/ "0.1.3";
    public static final String MINECRAFT = /*$ minecraft*/ "1.21";
    public static final class_5321<class_1887> CAPTURING = class_5321.method_29179(class_7924.field_41265, id(MOD_ID, "capturing"));
    public static final MapCodec<CapturingEnchantmentEffect> CAPTURING_EFFECT = class_2378.method_10230(class_7923.field_51834, id(MOD_ID, "capturing_effect"), CapturingEnchantmentEffect.CODEC);

    @Override
    public void onInitialize() {
        //? if <1.21 {
        // TODO: Implement pre 1.21 enchantment registration
        //?}
    }

    /**
     * Adapts to the {@link class_2960} changes introduced in 1.21.
     */
    public static class_2960 id(String namespace, String path) {
        //? if <1.21 {
        /*return new Identifier(namespace, path);
         *///?} else
        return class_2960.method_60655(namespace, path);
    }

}

==> mobcapture-0.1.4%2B1.21.1-sources.jar: de/kaama/mobcapture/MobCaptureMod.java <==
package de.kaama.mobcapture;

import net.fabricmc.api.ModInitializer;
import net.minecraft.class_1887;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
//? if >=1.21 {
import com.mojang.serialization.MapCodec;
import de.kaama.mobcapture.enchantment.effect.CapturingEnchantmentEffect;


public class MobCaptureMod implements ModInitializer {

    public static final String MOD_ID = "mobcapture";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);
    public static final String VERSION = /*$ mod_version*/ "0.1.4";
    public static final String MINECRAFT = /*$ minecraft*/ "1.21.1";
    public static final class_5321<class_1887> CAPTURING = class_5321.method_29179(class_7924.field_41265, id(MOD_ID, "capturing"));
    public static final MapCodec<CapturingEnchantmentEffect> CAPTURING_EFFECT = class_2378.method_10230(class_7923.field_51834, id(MOD_ID, "capturing_effect"), CapturingEnchantmentEffect.CODEC);

    @Override
    public void onInitialize() {
        //? if <1.21 {
        // TODO: Implement pre 1.21 enchantment registration
        //?}
    }

    /**
     * Adapts to the {@link class_2960} changes introduced in 1.21.
     */
    public static class_2960 id(String namespace, String path) {
        //? if <1.21 {
        /*return new Identifier(namespace, path);
         *///?} else
        return class_2960.method_60655(namespace, path);
    }

}
